==> owncloud-10.0.7.tgz: owncloud/lib/l10n/bn_BD.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" ডিরেক্টরিতে লেখা যায়না!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "সাধারণতঃ ওয়বসার্ভারকে কনফিগ ডিরেক্টরিতে লেখার অধিকার দিয়ে এই সমস্যা সমাধান করা যায়",
    "See %s" : "%s দেখ",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "সাধারণতঃ ওয়বসার্ভারকে কনফিগ ডিরেক্টরি%sতে লেখার অধিকার দিয়ে%s এই সমস্যা সমাধান করা যায়",
    "Sample configuration detected" : "নমুনা কনফিগারেশন পাওয়া গেছে",
    "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
    "Invalid image" : "অবৈধ চিত্র",
    "today" : "আজ",
    "yesterday" : "গতকাল",
    "last month" : "গত মাস",
    "last year" : "গত বছর",
    "seconds ago" : "সেকেন্ড পূর্বে",
    "None" : "কোনটিই নয়",
    "Username" : "ব্যবহারকারী",
    "Password" : "কূটশব্দ",
    "App directory already exists" : "এই অ্যাপ ডিরেক্টরিটি পূর্ব থেকেই বিদ্যমান",
    "Can't create app folder. Please fix permissions. %s" : "অ্যাপ ফোল্ডার বানানো হেলনা। অনুমতি নির্ধারণ করুন। %s",
    "No source specified when installing app" : "অ্যাপ ইনস্টল করতে যেয়ে কোন উৎস নির্দিষ্ট করা হয়নি",
    "Failed to open archive when installing app" : "অ্যাপ ইনস্টল করতে যেয়ে আর্কাইভ উম্মুক্তকরণ ব্যার্থ  হলো",
    "App does not provide an info.xml file" : "অ্যাপের সঙ্গে একটি  info.xml ফাইল নেই",
    "App can't be installed because of not allowed code in the App" : "অ্যাপের সাথে অননুমোদিত কোড থাকায় অ্যাপটি ইনস্টল করা যাবেনা",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "অ্যাপ ইনস্টল করা যাবেনা কারণ এতে ননশিপড অ্যাপ এর জন্য অননুমোদিত <shipped>true</shipped> ট্যাগ বিদ্যমান ",
    "Apps" : "অ্যাপ",
    "General" : "সাধারণ",
    "Storage" : "সংরক্ষণাগার",
    "Security" : "নিরাপত্তা",
    "Encryption" : "সংকেতায়ন",
    "Sharing" : "ভাগাভাগিরত",
    "Search" : "অনুসন্ধান",
    "%s shared »%s« with you" : "%s আপনার সাথে »%s« ভাগাভাগি করেছে",
    "Sharing %s failed, because the file does not exist" : "%s ভাগাভাগি ব্যার্থ, কারণ ফাইলটি নেই",
    "You are not allowed to share %s" : "আপনি %s ভাগাভাগি করতে পারবেননা",
    "Help" : "সহায়িকা",
    "Settings" : "নিয়ামকসমূহ",
    "Users" : "ব্যবহারকারী",
    "web services under your control" : "ওয়েব সার্ভিস আপনার হাতের মুঠোয়",
    "Application is not enabled" : "অ্যাপ্লিকেসনটি সক্রিয় নয়",
    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
    "Token expired. Please reload page." : "টোকেন মেয়াদোত্তীর্ণ। দয়া করে পৃষ্ঠাটি পূনরায় লোড করুন।",
    "Unknown user" : "অপরিচিত ব্যবহারকারী"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/bn_BD.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" ডিরেক্টরিতে লেখা যায়না!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "সাধারণতঃ ওয়বসার্ভারকে কনফিগ ডিরেক্টরিতে লেখার অধিকার দিয়ে এই সমস্যা সমাধান করা যায়",
    "See %s" : "%s দেখ",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "সাধারণতঃ ওয়বসার্ভারকে কনফিগ ডিরেক্টরি%sতে লেখার অধিকার দিয়ে%s এই সমস্যা সমাধান করা যায়",
    "Sample configuration detected" : "নমুনা কনফিগারেশন পাওয়া গেছে",
    "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
    "Invalid image" : "অবৈধ চিত্র",
    "today" : "আজ",
    "yesterday" : "গতকাল",
    "last month" : "গত মাস",
    "last year" : "গত বছর",
    "seconds ago" : "সেকেন্ড পূর্বে",
    "None" : "কোনটিই নয়",
    "Username" : "ব্যবহারকারী",
    "Password" : "কূটশব্দ",
    "App directory already exists" : "এই অ্যাপ ডিরেক্টরিটি পূর্ব থেকেই বিদ্যমান",
    "Can't create app folder. Please fix permissions. %s" : "অ্যাপ ফোল্ডার বানানো হেলনা। অনুমতি নির্ধারণ করুন। %s",
    "No source specified when installing app" : "অ্যাপ ইনস্টল করতে যেয়ে কোন উৎস নির্দিষ্ট করা হয়নি",
    "Failed to open archive when installing app" : "অ্যাপ ইনস্টল করতে যেয়ে আর্কাইভ উম্মুক্তকরণ ব্যার্থ  হলো",
    "App does not provide an info.xml file" : "অ্যাপের সঙ্গে একটি  info.xml ফাইল নেই",
    "App can't be installed because of not allowed code in the App" : "অ্যাপের সাথে অননুমোদিত কোড থাকায় অ্যাপটি ইনস্টল করা যাবেনা",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "অ্যাপ ইনস্টল করা যাবেনা কারণ এতে ননশিপড অ্যাপ এর জন্য অননুমোদিত <shipped>true</shipped> ট্যাগ বিদ্যমান ",
    "Apps" : "অ্যাপ",
    "General" : "সাধারণ",
    "Storage" : "সংরক্ষণাগার",
    "Security" : "নিরাপত্তা",
    "Encryption" : "সংকেতায়ন",
    "Sharing" : "ভাগাভাগিরত",
    "Search" : "অনুসন্ধান",
    "%s shared »%s« with you" : "%s আপনার সাথে »%s« ভাগাভাগি করেছে",
    "Sharing %s failed, because the file does not exist" : "%s ভাগাভাগি ব্যার্থ, কারণ ফাইলটি নেই",
    "You are not allowed to share %s" : "আপনি %s ভাগাভাগি করতে পারবেননা",
    "Help" : "সহায়িকা",
    "Settings" : "নিয়ামকসমূহ",
    "Users" : "ব্যবহারকারী",
    "web services under your control" : "ওয়েব সার্ভিস আপনার হাতের মুঠোয়",
    "Application is not enabled" : "অ্যাপ্লিকেসনটি সক্রিয় নয়",
    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
    "Token expired. Please reload page." : "টোকেন মেয়াদোত্তীর্ণ। দয়া করে পৃষ্ঠাটি পূনরায় লোড করুন।",
    "Unknown user" : "অপরিচিত ব্যবহারকারী",
    "Imprint" : "প্রতিচ্ছাপ",
    "__language_name__" : "__language_name__"
},
"nplurals=2; plural=(n != 1);");
